"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.doujinMeta = exports.DoujinMeta = void 0;
const axios_1 = __importDefault(require("axios"));
const metadata_source_1 = require("../metadata-source");
const normalize_1 = require("../normalize/normalize");
const doujinMetaApi = axios_1.default.create({
    // eslint-disable-next-line @typescript-eslint/naming-convention
    baseURL: 'https://doujin-meta.vercel.app',
    responseType: 'json',
});
class DoujinMeta extends metadata_source_1.MetadataSource {
    async resolveAlbumName(albumName) {
        const { data: searchResult } = await doujinMetaApi.get(`/api/albums/search/${encodeURIComponent(albumName)}`);
        if (searchResult.length > 0 && searchResult[0].name === albumName) {
            return albumName;
        }
        return searchResult.map(it => it.name).slice(0, metadata_source_1.MetadataSource.MaxSearchCount);
    }
    async getMetadata(albumName, cover) {
        const { data: albumDetail } = await doujinMetaApi.get(`/api/albums/detail/${encodeURIComponent(albumName)}`);
        const downloadCover = async () => {
            const { data: coverData } = await doujinMetaApi.get(albumDetail.coverUrl, {
                responseType: 'arraybuffer',
            });
            return coverData;
        };
        const coverBuffer = cover ?? (await downloadCover());
        return (0, normalize_1.expandMetadataInfo)({
            metadatas: albumDetail.metadata,
            cover: coverBuffer,
        });
    }
}
exports.DoujinMeta = DoujinMeta;
exports.doujinMeta = new DoujinMeta();
