"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.simplifyNumberPlugin = exports.expandNumberPlugin = void 0;
/** 自动推测 trackNumber 和 discNumber */
const expandNumberPlugin = () => {
    const cachedNumber = {
        track: 1,
        disc: 1,
    };
    return ({ metadata }) => {
        const discNumberFromMetadata = metadata.discNumber !== undefined ? parseInt(metadata.discNumber) : NaN;
        if (!Number.isNaN(discNumberFromMetadata) && discNumberFromMetadata !== cachedNumber.disc) {
            cachedNumber.disc = discNumberFromMetadata;
            cachedNumber.track = 1;
        }
        if (!metadata.discNumber) {
            metadata.discNumber = cachedNumber.disc.toString();
        }
        if (!metadata.trackNumber) {
            metadata.trackNumber = cachedNumber.track.toString();
        }
        cachedNumber.track += 1;
    };
};
exports.expandNumberPlugin = expandNumberPlugin;
/** 自动省略 trackNumber 和 discNumber */
const simplifyNumberPlugin = () => {
    const cachedNumber = {
        track: 1,
        disc: 1,
    };
    return ({ metadata }) => {
        if (metadata.discNumber !== undefined) {
            const discNumber = parseInt(metadata.discNumber);
            if (Number.isNaN(discNumber) || discNumber === cachedNumber.disc) {
                delete metadata.discNumber;
            }
            else if (discNumber !== cachedNumber.disc) {
                cachedNumber.disc = discNumber;
                cachedNumber.track = 1;
            }
        }
        if (metadata.trackNumber !== undefined) {
            const trackNumber = parseInt(metadata.trackNumber);
            if (Number.isNaN(trackNumber) || trackNumber === cachedNumber.track) {
                delete metadata.trackNumber;
            }
        }
        cachedNumber.track += 1;
    };
};
exports.simplifyNumberPlugin = simplifyNumberPlugin;
